summaryrefslogtreecommitdiffstats
path: root/Source/cmCableInstantiateClassCommand.h
diff options
context:
space:
mode:
authorBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
committerBrad King <brad.king@kitware.com>2001-02-28 14:34:01 (GMT)
commitd0a8794746f6de026f1c69652cd09caf8be9cfab (patch)
tree2143ad59bf1fef6f340dd7fb199f556eadff0ef4 /Source/cmCableInstantiateClassCommand.h
parente5e2a57bfbf1aac2c265e894db82d2b2d5673084 (diff)
downloadCMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.zip
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.gz
CMake-d0a8794746f6de026f1c69652cd09caf8be9cfab.tar.bz2
ENH: CABIL -> CABLE rename.
Diffstat (limited to 'Source/cmCableInstantiateClassCommand.h')
-rw-r--r--Source/cmCableInstantiateClassCommand.h26
1 files changed, 13 insertions, 13 deletions
diff --git a/Source/cmCableInstantiateClassCommand.h b/Source/cmCableInstantiateClassCommand.h
index b02b28a..1162992 100644
--- a/Source/cmCableInstantiateClassCommand.h
+++ b/Source/cmCableInstantiateClassCommand.h
@@ -13,21 +13,21 @@
See COPYRIGHT.txt for copyright details.
=========================================================================*/
-#ifndef cmCabilInstantiateClassCommand_h
-#define cmCabilInstantiateClassCommand_h
+#ifndef cmCableInstantiateClassCommand_h
+#define cmCableInstantiateClassCommand_h
#include "cmStandardIncludes.h"
-#include "cmCabilInstantiateCommand.h"
+#include "cmCableInstantiateCommand.h"
-/** \class cmCabilInstantiateClassCommand
+/** \class cmCableInstantiateClassCommand
* \brief Define a command that generates a rule for explicit template
* instantiations of classes.
*
* cmCabilInstantiateCommand is used to generate a rule in a CABIL
* configuration file to create explicit template instantiations of
* classes.
*/
-class cmCabilInstantiateClassCommand : public cmCabilInstantiateCommand
+class cmCableInstantiateClassCommand : public cmCableInstantiateCommand
{
public:
/**
@@ -35,20 +35,20 @@ public:
*/
virtual cmCommand* Clone()
{
- return new cmCabilInstantiateClassCommand;
+ return new cmCableInstantiateClassCommand;
}
/**
* The name of the command as specified in CMakeList.txt.
*/
- virtual const char* GetName() { return "CABIL_INSTANTIATE_CLASS";}
+ virtual const char* GetName() { return "CABLE_INSTANTIATE_CLASS";}
/**
* Succinct documentation.
*/
virtual const char* GetTerseDocumentation()
{
- return "Define CABIL InstantiationSet of classes.";
+ return "Define CABLE InstantiationSet of classes.";
}
/**
@@ -57,17 +57,17 @@ public:
virtual const char* GetFullDocumentation()
{
return
- "CABIL_INSTANTIATE_CLASS(cabil_config_file member1 member2 ...)\n"
- "Generates an InstantiationSet in the CABIL configuration. It is\n"
+ "CABLE_INSTANTIATE_CLASS(cable_config_file member1 member2 ...)\n"
+ "Generates an InstantiationSet in the CABLE configuration. It is\n"
"assumed that all members of the set are explicit instantiations of\n"
"template classes (not functions, operators, etc).";
}
virtual void WriteConfiguration(std::ostream&) const;
- cmTypeMacro(cmCabilInstantiateClassCommand, cmCabilInstantiateCommand);
+ cmTypeMacro(cmCableInstantiateClassCommand, cmCableInstantiateCommand);
protected:
- typedef cmCabilInstantiateCommand::Elements Elements;
+ typedef cmCableInstantiateCommand::Elements Elements;
};
@@ -13,21 +13,21 @@
* instantiations of classes.
*
- * cmCabilInstantiateCommand is used to generate a rule in a CABIL
+ * cmCableInstantiateCommand is used to generate a rule in a CABLE
* configuration file to create explicit template instantiations of
* classes.